@@ -1,5 +1,5 @@
 package CPAN::Testers::API::Controller::Summary;
-our $VERSION = '0.021';
+our $VERSION = '0.022';
 # ABSTRACT: API for test report summary data
 
 #pod =head1 DESCRIPTION
@@ -60,11 +60,14 @@ sub summary( $c ) {
     my $dist = $c->validation->param( 'dist' );
     my $version = $c->validation->param( 'version' );
 
+    my $grade = $c->validation->param( 'grade' );
+
     my $rs = $c->schema->resultset( 'Stats' );
     $rs = $rs->search(
         {
             dist => $dist,
             version => $version,
+            ( $grade ? ( state => $grade ) : () ),
         },
         {
             columns => [qw( guid fulldate state tester dist version platform perl osname osvers )],
@@ -106,7 +109,7 @@ CPAN::Testers::API::Controller::Summary - API for test report summary data
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 DESCRIPTION
 
